@@ -1,11 +1,8 @@
 """
-Loader for the STRIP AI dataset
-
-Slides are tiffs read using openslide
-
-A single annotation is applied to whole slide
-
-Output labels for slides are background, CE and LAA
+Loader for the STRIP AI dataset.
+    - Slides are tiffs read using openslide
+    - A single annotation is applied to whole slide
+    - Output labels for slides are background, CE and LAA
 
 """
 
@@ -22,10 +19,11 @@ class StripaiLoader(Loader):
     def name(self) -> str:
         return "StripaiLoader"
 
-    def load_annotations(self, label: str) -> AnnotationSet:
+    def load_annotations(self, label: Path) -> AnnotationSet:
         # if there is no annotation file the just pass and empty list
         annotations = []
         labels_order = ["background", "Other", "CE", "LAA"]
+        label = str(label.stem)
         return AnnotationSet(annotations, self.labels, labels_order, label)
 
     def load_slide(self, path: Path) -> SlideBase:
