@@ -1,3 +1,6 @@
+"""
+Functionality for converting between formats.
+"""
 from typing import Dict
 
 import numpy as np
@@ -6,7 +9,7 @@ from PIL import Image
 import pandas as pd
 
 
-def pil_to_np(image: Image) -> np.ndarray:
+def pil_to_np(image: Image.Image) -> np.ndarray:
     """ Convert a PIL image into a Numpy array
 
     Args:
@@ -20,7 +23,7 @@ def pil_to_np(image: Image) -> np.ndarray:
     return arr
 
 
-def np_to_pil(arr: np.ndarray) -> Image:
+def np_to_pil(arr: np.ndarray) -> Image.Image:
     """ Convert a Numpy array into a PIL image
 
     Args:
@@ -34,6 +37,8 @@ def np_to_pil(arr: np.ndarray) -> Image:
         arr = arr.astype("uint8") * 255
     elif arr.dtype == "float64" or arr.dtype == "float32":
         arr = (arr * 255).astype("uint8")
+    elif arr.dtype == "int64":
+        arr = arr.astype("uint8")
     return Image.fromarray(arr)
 
 
